netapp_ontap.models.volume_encryption_support API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_encryption_support`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeEncryptionSupportSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeEncryptionSupport object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: Size GET`

    Code corresponding to the status message. Returns a 0 if volume encryption is supported in all nodes of the cluster.

    Example: 346758

  `message: str GET`

    Reason for not supporting volume encryption.

    Example: No platform support for volume encryption in following nodes - node1, node2.

  `supported: bool GET`

    Set to true when volume encryption support is available on all nodes of the cluster.